module Rubroxy
  module Handler
    # Captures URLs, stores the results in a hash as the handler
    # Proc object is called.
    class URLCapture
      attr_accessor :collection

      # Creates a new URLCapture object. Sets up the hash to store URLs
      #
      # @return [Hash]
      def initialize
        setup_collection
      end

      # Writes to the URL collection. It attempts to find the key matching the
      # URL captured and increments the value if found. If not, it will create
      # a new key value pair.
      #
      # @param url [String] the url captured by the handler Proc
      # @return [Hash]
      def write(url)
        if @collection[:uris].key?(url)
          @collection[:uris][url] += 1
        else
          @collection[:uris].merge!(url => 1)
        end
      end

      # Clears the objects URL hash.
      #
      # @return [Hash]
      def clear
        setup_collection
      end

      private

      # Called by public methods to setup the correct hash structure.
      #
      # @return [Hash]
      def setup_collection
        @collection = { uris: {} }
      end
    end
  end
end
